@@ -37,11 +37,15 @@ async def gql(
     query_str: str,
     variables: dict = None,
     should_print: bool = False,
+    use_one_time: bool = False,
 ) -> dict:
     start = time.time()
-    response = await client.post(
-        url=url, json={"query": query_str, "variables": variables or {}}
-    )
+    json = {"query": query_str, "variables": variables or {}}
+    if use_one_time:
+        async with httpx.AsyncClient() as onetime_client:
+            response = await onetime_client.post(url=url, json=json)
+    else:
+        response = await client.post(url=url, json=json)
     return finish(
         response=response,
         query_str=query_str,
