@@ -369,13 +369,19 @@ class Node(BaseModel):
         inputs: T.List[GQL.add_model],
         given_resolver: T.Optional[ResolverType] = None,
         upsert: bool = None,
+        use_one_time: bool = False,
     ) -> T.List[NodeModel]:
         resolver = given_resolver or cls.GQL.resolver()
         query_str = resolver.make_add_mutation_str(include_upsert=upsert is not None)
         variables = {"input": jsonable_encoder(inputs)}
         if upsert is not None:
             variables["upsert"] = upsert
-        j = await gql(query_str=query_str, variables=variables, url=cls.GQL.url)
+        j = await gql(
+            query_str=query_str,
+            variables=variables,
+            url=cls.GQL.url,
+            use_one_time=use_one_time,
+        )
         node_d_lst = j["data"][f"{cls.GQL.add_function_name}"][
             cls.GQL.payload_node_name
         ]
